@@ -1,14 +1,14 @@
-#' The GSEA GenePattern Color Palettes
+#' The GSEA GenePattern color palettes
 #'
 #' Color palette inspired by the colors used in the
 #' heatmaps plotted by GSEA GenePattern.
 #'
 #' @param palette Palette type.
-#' Currently there is one available option: \code{"default"}
-#' (continuous palette with 12 base colors).
+#'   Currently there is one available option: `"default"`
+#'   (continuous palette with 12 base colors).
 #' @param n Number of individual colors to be generated.
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #' @param reverse Logical. Should the order of the colors be reversed?
 #'
 #' @export rgb_gsea
@@ -16,11 +16,10 @@
 #' @importFrom grDevices colorRamp rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @note The 12 base colors used in this palette are derived from the
-#' \href{https://modulerepository.genepattern.org/gpModuleRepository/download/prod/module/?file=/HeatMapImage/broad.mit.edu:cancer.software.genepattern.module.analysis/00032/6/HeatMapImage.pdf}{HeatMapImage documentation}.
+#' [HeatMapImage documentation](https://modulerepository.genepattern.org/gpModuleRepository/download/prod/module/?file=/HeatMapImage/broad.mit.edu:cancer.software.genepattern.module.analysis/00032/6/HeatMapImage.pdf).
 #'
 #' @examples
 #' library("scales")
@@ -29,7 +28,7 @@
 rgb_gsea <- function(palette = c("default"), n = 12, alpha = 1, reverse = FALSE) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"gsea"[[palette]]
   func_cols <- colorRamp(raw_cols, space = "Lab", interpolate = "spline")
@@ -44,7 +43,7 @@ rgb_gsea <- function(palette = c("default"), n = 12, alpha = 1, reverse = FALSE)
   alpha_cols
 }
 
-#' The GSEA GenePattern Color Palettes
+#' The GSEA GenePattern color palettes
 #'
 #' Color palette inspired by the colors used in the
 #' heatmaps plotted by GSEA GenePattern.
@@ -55,8 +54,7 @@ rgb_gsea <- function(palette = c("default"), n = 12, alpha = 1, reverse = FALSE)
 #'
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @examples
 #' library("scales")
@@ -68,36 +66,39 @@ pal_gsea <- function(palette = c("default"), n = 12, alpha = 1, reverse = FALSE)
   manual_pal(unname(alpha_cols))
 }
 
-#' The GSEA GenePattern Color Scales
+#' The GSEA GenePattern color scales
 #'
-#' See \code{\link{pal_gsea}} for details.
+#' See [pal_gsea()] for details.
 #'
 #' @inheritParams pal_gsea
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_gsea
 #'
 #' @importFrom ggplot2 scale_color_gradientn
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_gsea
 #'
 #' @examples
 #' library("ggplot2")
-#' library("reshape2")
-#' data("mtcars")
 #'
+#' data("mtcars")
 #' cor <- cor(mtcars)
-#' cor_melt <- melt(cor)
+#' cor_melt <- data.frame(
+#'   Var1 = rep(seq_len(nrow(cor)), times = ncol(cor)),
+#'   Var2 = rep(seq_len(ncol(cor)), each = nrow(cor)),
+#'   value = as.vector(cor)
+#' )
 #'
 #' ggplot(
 #'   cor_melt,
 #'   aes(x = Var1, y = Var2, fill = value)
 #' ) +
 #'   geom_tile(colour = "black", size = 0.3) +
-#'   theme_bw() + scale_fill_gsea()
+#'   theme_bw() +
+#'   scale_fill_gsea()
 scale_color_gsea <- function(palette = c("default"), alpha = 1, reverse = FALSE, ...) {
   palette <- match.arg(palette)
   scale_color_gradientn(colours = rgb_gsea(palette, n = 512, alpha = alpha, reverse = reverse), ...)
