@@ -1,22 +1,21 @@
-#' AAAS Journal Color Palettes
+#' AAAS journal color palettes
 #'
 #' Color palettes inspired by plots in journals published by
 #' American Association for the Advancement of Science (AAAS),
-#' such as \emph{Science} and \emph{Science Translational Medicine}.
+#' such as _Science_ and _Science Translational Medicine_.
 #'
 #' @param palette Palette type.
-#' Currently there is one available option: \code{"default"}
-#' (10-color palette inspired by \emph{Science}).
+#'   Currently there is one available option: `"default"`
+#'   (10-color palette inspired by _Science_).
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #'
 #' @export pal_aaas
 #'
 #' @importFrom grDevices col2rgb rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @examples
 #' library("scales")
@@ -25,7 +24,7 @@
 pal_aaas <- function(palette = c("default"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"aaas"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -38,19 +37,18 @@ pal_aaas <- function(palette = c("default"), alpha = 1) {
   manual_pal(unname(alpha_cols))
 }
 
-#' AAAS Journal Color Scales
+#' AAAS journal color scales
 #'
-#' See \code{\link{pal_aaas}} for details.
+#' See [pal_aaas()] for details.
 #'
 #' @inheritParams pal_aaas
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_aaas
 #'
 #' @importFrom ggplot2 discrete_scale
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_aaas
 #'
@@ -64,17 +62,23 @@ pal_aaas <- function(palette = c("default"), alpha = 1) {
 #' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_aaas()
+#'   theme_bw() +
+#'   scale_color_aaas()
 #'
 #' ggplot(
 #'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
 #'   aes(x = depth, fill = cut)
 #' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_aaas()
+#'   theme_bw() +
+#'   scale_fill_aaas()
 scale_color_aaas <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "aaas", pal_aaas(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_aaas(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "aaas", palette = pal_aaas(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_aaas
@@ -86,5 +90,9 @@ scale_colour_aaas <- scale_color_aaas
 #' @rdname scale_aaas
 scale_fill_aaas <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "aaas", pal_aaas(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_aaas(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "aaas", palette = pal_aaas(palette, alpha), ...)
+  }
 }
