@@ -1,20 +1,19 @@
-#' The Futurama Color Palettes
+#' Futurama color palettes
 #'
-#' Color palettes inspired by the colors used in \emph{Futurama}.
+#' Color palettes inspired by the colors used in _Futurama_.
 #'
 #' @param palette Palette type.
-#' Currently there is one available option: \code{"planetexpress"}
-#' (12-color palette).
+#'   Currently there is one available option: `"planetexpress"`
+#'   (12-color palette).
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #'
 #' @export pal_futurama
 #'
 #' @importFrom grDevices col2rgb rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @examples
 #' library("scales")
@@ -23,7 +22,7 @@
 pal_futurama <- function(palette = c("planetexpress"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"futurama"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -36,19 +35,18 @@ pal_futurama <- function(palette = c("planetexpress"), alpha = 1) {
   manual_pal(unname(alpha_cols))
 }
 
-#' The Futurama Color Scales
+#' Futurama color scales
 #'
-#' See \code{\link{pal_futurama}} for details.
+#' See [pal_futurama()] for details.
 #'
 #' @inheritParams pal_futurama
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_futurama
 #'
 #' @importFrom ggplot2 discrete_scale
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_futurama
 #'
@@ -62,17 +60,23 @@ pal_futurama <- function(palette = c("planetexpress"), alpha = 1) {
 #' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_futurama()
+#'   theme_bw() +
+#'   scale_color_futurama()
 #'
 #' ggplot(
 #'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
 #'   aes(x = depth, fill = cut)
 #' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_futurama()
+#'   theme_bw() +
+#'   scale_fill_futurama()
 scale_color_futurama <- function(palette = c("planetexpress"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "futurama", pal_futurama(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_futurama(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "futurama", palette = pal_futurama(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_futurama
@@ -84,5 +88,9 @@ scale_colour_futurama <- scale_color_futurama
 #' @rdname scale_futurama
 scale_fill_futurama <- function(palette = c("planetexpress"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "futurama", pal_futurama(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_futurama(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "futurama", palette = pal_futurama(palette, alpha), ...)
+  }
 }
