@@ -1,27 +1,26 @@
-#' Integrative Genomics Viewer (IGV) Color Palettes
+#' Integrative Genomics Viewer (IGV) color palettes
 #'
 #' Color palettes based on the colors used by
 #' Integrative Genomics Viewer (IGV).
 #'
 #' @param palette Palette type.
-#' There are two available options:
-#' \code{"default"} (51-color palette);
-#' \code{"alternating"} (2-color palette).
+#'   There are two available options:
+#'   - `"default"` (51-color palette).
+#'   - `"alternating"` (2-color palette).
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #'
 #' @export pal_igv
 #'
 #' @importFrom grDevices col2rgb rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @references
 #' James T. Robinson, Helga Thorvaldsdóttir, Wendy Winckler,
 #' Mitchell Guttman, Eric S. Lander, Gad Getz, Jill P. Mesirov.
-#' Integrative Genomics Viewer. \emph{Nature Biotechnology} 29, 24--26 (2011).
+#' Integrative Genomics Viewer. _Nature Biotechnology_ 29, 24--26 (2011).
 #'
 #' @examples
 #' library("scales")
@@ -30,7 +29,7 @@
 pal_igv <- function(palette = c("default", "alternating"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"igv"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -43,19 +42,18 @@ pal_igv <- function(palette = c("default", "alternating"), alpha = 1) {
   manual_pal(unname(alpha_cols))
 }
 
-#' Integrative Genomics Viewer (IGV) Color Scales
+#' Integrative Genomics Viewer (IGV) color scales
 #'
-#' See \code{\link{pal_igv}} for details.
+#' See [pal_igv()] for details.
 #'
 #' @inheritParams pal_igv
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_igv
 #'
 #' @importFrom ggplot2 discrete_scale
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_igv
 #'
@@ -89,7 +87,11 @@ pal_igv <- function(palette = c("default", "alternating"), alpha = 1) {
 #' )
 scale_color_igv <- function(palette = c("default", "alternating"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "igv", pal_igv(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_igv(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "igv", palette = pal_igv(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_igv
@@ -101,5 +103,9 @@ scale_colour_igv <- scale_color_igv
 #' @rdname scale_igv
 scale_fill_igv <- function(palette = c("default", "alternating"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "igv", pal_igv(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_igv(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "igv", palette = pal_igv(palette, alpha), ...)
+  }
 }
