@@ -1,21 +1,20 @@
-#' NEJM Color Palettes
+#' NEJM color palettes
 #'
 #' Color palette inspired by plots in
-#' \emph{The New England Journal of Medicine}.
+#' _The New England Journal of Medicine_.
 #'
 #' @param palette Palette type.
-#' Currently there is one available option: \code{"default"}
-#' (8-color palette).
+#'   Currently there is one available option: `"default"`
+#'   (8-color palette).
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #'
 #' @export pal_nejm
 #'
 #' @importFrom grDevices col2rgb rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @examples
 #' library("scales")
@@ -24,7 +23,7 @@
 pal_nejm <- function(palette = c("default"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"nejm"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -37,43 +36,48 @@ pal_nejm <- function(palette = c("default"), alpha = 1) {
   manual_pal(unname(alpha_cols))
 }
 
-#' NEJM Color Scales
+#' NEJM color scales
 #'
-#' See \code{\link{pal_nejm}} for details.
+#' See [pal_nejm()] for details.
 #'
 #' @inheritParams pal_nejm
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_nejm
 #'
 #' @importFrom ggplot2 discrete_scale
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_nejm
 #'
 #' @examples
 #' library("ggplot2")
 #' data("diamonds")
-#' 
+#'
 #' ggplot(
 #'   subset(diamonds, carat >= 2.2),
 #'   aes(x = table, y = price, colour = cut)
 #' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_nejm()
-#' 
+#'   theme_bw() +
+#'   scale_color_nejm()
+#'
 #' ggplot(
 #'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
 #'   aes(x = depth, fill = cut)
 #' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_nejm()
+#'   theme_bw() +
+#'   scale_fill_nejm()
 scale_color_nejm <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "nejm", pal_nejm(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_nejm(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "nejm", palette = pal_nejm(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_nejm
@@ -85,5 +89,9 @@ scale_colour_nejm <- scale_color_nejm
 #' @rdname scale_nejm
 scale_fill_nejm <- function(palette = c("default"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "nejm", pal_nejm(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_nejm(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "nejm", palette = pal_nejm(palette, alpha), ...)
+  }
 }
