@@ -1,21 +1,20 @@
-#' NPG Journal Color Palettes
+#' NPG journal color palettes
 #'
 #' Color palettes inspired by plots in journals published by
-#' Nature Publishing Group, such as \emph{Nature Reviews Cancer}.
+#' Nature Publishing Group, such as _Nature Reviews Cancer_.
 #'
 #' @param palette Palette type.
-#' Currently there is one available option: \code{"nrc"}
-#' (10-color palette inspired by \emph{Nature Reviews Cancer}).
+#'   Currently there is one available option: `"nrc"`
+#'   (10-color palette inspired by _Nature Reviews Cancer_).
 #' @param alpha Transparency level, a real number in (0, 1].
-#' See \code{alpha} in \code{\link[grDevices]{rgb}} for details.
+#'   See `alpha` in [grDevices::rgb()] for details.
 #'
 #' @export pal_npg
 #'
 #' @importFrom grDevices col2rgb rgb
 #' @importFrom scales manual_pal
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @examples
 #' library("scales")
@@ -24,7 +23,7 @@
 pal_npg <- function(palette = c("nrc"), alpha = 1) {
   palette <- match.arg(palette)
 
-  if (alpha > 1L | alpha <= 0L) stop("alpha must be in (0, 1]")
+  if (alpha > 1L || alpha <= 0L) stop("alpha must be in (0, 1]")
 
   raw_cols <- ggsci_db$"npg"[[palette]]
   raw_cols_rgb <- col2rgb(raw_cols)
@@ -37,43 +36,48 @@ pal_npg <- function(palette = c("nrc"), alpha = 1) {
   manual_pal(unname(alpha_cols))
 }
 
-#' NPG Journal Color Scales
+#' NPG journal color scales
 #'
-#' See \code{\link{pal_npg}} for details.
+#' See [pal_npg()] for details.
 #'
 #' @inheritParams pal_npg
-#' @param ... additional parameters for \code{\link[ggplot2]{discrete_scale}}
+#' @param ... Additional parameters for [ggplot2::discrete_scale()].
 #'
 #' @export scale_color_npg
 #'
 #' @importFrom ggplot2 discrete_scale
 #'
-#' @author Nan Xiao <\email{me@@nanx.me}> |
-#' <\href{https://nanx.me}{https://nanx.me}>
+#' @author Nan Xiao | \email{me@nanx.me} | <https://nanx.me>
 #'
 #' @rdname scale_npg
 #'
 #' @examples
 #' library("ggplot2")
 #' data("diamonds")
-#' 
+#'
 #' ggplot(
 #'   subset(diamonds, carat >= 2.2),
 #'   aes(x = table, y = price, colour = cut)
 #' ) +
 #'   geom_point(alpha = 0.7) +
 #'   geom_smooth(method = "loess", alpha = 0.1, size = 1, span = 1) +
-#'   theme_bw() + scale_color_npg()
-#' 
+#'   theme_bw() +
+#'   scale_color_npg()
+#'
 #' ggplot(
 #'   subset(diamonds, carat > 2.2 & depth > 55 & depth < 70),
 #'   aes(x = depth, fill = cut)
 #' ) +
 #'   geom_histogram(colour = "black", binwidth = 1, position = "dodge") +
-#'   theme_bw() + scale_fill_npg()
+#'   theme_bw() +
+#'   scale_fill_npg()
 scale_color_npg <- function(palette = c("nrc"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("colour", "npg", pal_npg(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("colour", palette = pal_npg(palette, alpha), ...)
+  } else {
+    discrete_scale("colour", scale_name = "npg", palette = pal_npg(palette, alpha), ...)
+  }
 }
 
 #' @export scale_colour_npg
@@ -85,5 +89,9 @@ scale_colour_npg <- scale_color_npg
 #' @rdname scale_npg
 scale_fill_npg <- function(palette = c("nrc"), alpha = 1, ...) {
   palette <- match.arg(palette)
-  discrete_scale("fill", "npg", pal_npg(palette, alpha), ...)
+  if (is_ggplot2_350()) {
+    discrete_scale("fill", palette = pal_npg(palette, alpha), ...)
+  } else {
+    discrete_scale("fill", scale_name = "npg", palette = pal_npg(palette, alpha), ...)
+  }
 }
